fqdn static method
Ensures the string is a fully qualified domain name.
Implementation
static String? Function(String?) fqdn({
String errorMessage = 'Please enter a valid domain name',
}) {
return _build(errorMessage, (v) => v.isFQDN);
}
Ensures the string is a fully qualified domain name.
static String? Function(String?) fqdn({
String errorMessage = 'Please enter a valid domain name',
}) {
return _build(errorMessage, (v) => v.isFQDN);
}