isAlphanumeric property
bool
get
isAlphanumeric
Checks if the string contains only letters and numbers.
Implementation
bool get isAlphanumeric {
return _isAlphanumeric(this);
}
Checks if the string contains only letters and numbers.
bool get isAlphanumeric {
return _isAlphanumeric(this);
}