isFQDN property
bool
get
isFQDN
Checks if the string is a fully qualified domain name (FQDN).
Implementation
bool get isFQDN {
return _isFQDN(this);
}
Checks if the string is a fully qualified domain name (FQDN).
bool get isFQDN {
return _isFQDN(this);
}