isLength function

bool isLength(
  1. String str,
  2. int min, [
  3. int? max
])

Checks if the string's length falls in a range.

The length of the string must be at least min. If max is provided, the length must also be at most max.

Example:

isLength('abc', 2); // true
isLength('abc', 4); // false
isLength('abc', 1, 3); // true

Implementation

bool isLength(String str, int min, [int? max]) => _isLength(str, min, max);