isPort property
bool
get
isPort
Checks if the string is a valid port number.
Implementation
bool get isPort {
return _isPort(this);
}
Checks if the string is a valid port number.
bool get isPort {
return _isPort(this);
}