BlacklistX extension

Extension providing character filtering sanitizers on String.

on

Methods

blacklist(String chars) → String

Available on String, provided by the BlacklistX extension

Removes all characters that appear in chars from the string.
whitelist(String chars) → String

Available on String, provided by the BlacklistX extension

Removes all characters that do not appear in chars from the string.