normalizeEmail function

String? normalizeEmail(
  1. String str
)

Canonicalizes an email address.

Lowercases the domain and, for Gmail addresses, lowercases the local part, removes dots and strips any +tag suffix. Returns null if the input is not a valid email address.

Example:

normalizeEmail('Test.User+tag@GMAIL.com'); // 'testuser@gmail.com'
normalizeEmail('User@Example.COM'); // 'User@example.com'
normalizeEmail('not-an-email'); // null

Implementation

String? normalizeEmail(String str) => _normalizeEmail(str);