ToNumberX extension

Extension providing numeric and date conversions on String.

on

Methods

toDate() DateTime?

Available on String, provided by the ToNumberX extension

Converts this string to a DateTime, or null if it cannot be parsed.
toFloat() double?

Available on String, provided by the ToNumberX extension

Converts this string to a double, or null if it cannot be parsed.
toInt({int? radix}) int?

Available on String, provided by the ToNumberX extension

Converts this string to an integer, or null if it cannot be parsed.