toFloat method
Converts this string to a double, or null if it cannot be parsed.
Implementation
double? toFloat() => double.tryParse(trim());
Converts this string to a double, or null if it cannot be parsed.
double? toFloat() => double.tryParse(trim());