validators/sanitizers/trim library

Extensions

TrimX on String
Extension providing trimming sanitizers on String.

Functions

ltrim(String str, [String? chars]) String
Removes the given chars from the start of the string.
rtrim(String str, [String? chars]) String
Removes the given chars from the end of the string.
trim(String str, [String? chars]) String
Removes the given chars from both ends of the string.