isSemVer property
bool
get
isSemVer
Checks if the string is a valid Semantic Version (SemVer).
Implementation
bool get isSemVer {
return _isSemVer(this);
}
Checks if the string is a valid Semantic Version (SemVer).
bool get isSemVer {
return _isSemVer(this);
}