AlphaX extension
Extension providing alpha and alphanumeric validation methods on String.
Properties
-
isAlpha
→ bool
-
Available on String,
provided by the AlphaX extension
Checks if the string contains only letters (a-z, A-Z).
no setter
-
isAlphanumeric
→ bool
-
Available on String,
provided by the AlphaX extension
Checks if the string contains only letters and numbers.
no setter