TrimX extension

Extension providing trimming sanitizers on String.

on

Methods

ltrimChars(String chars) → String

Available on String, provided by the TrimX extension

Removes the given chars from the start of the string.
rtrimChars(String chars) → String

Available on String, provided by the TrimX extension

Removes the given chars from the end of the string.
trimChars(String chars) → String

Available on String, provided by the TrimX extension

Removes the given chars from both ends of the string.